@@ -1,6 +1,5 @@
 ''' Tests for runpod | serverless| modules | pod_worker.py '''
 
-import os
 import unittest
 from unittest.mock import patch
 
@@ -11,20 +10,18 @@ class TestPodWorker(unittest.TestCase):
     ''' Tests for pod_worker '''
 
     @patch('runpod.serverless.modules.job.get', return_value=None)
-    @patch('runpod.serverless.modules.lifecycle.LifecycleManager.heartbeat_ping')
     @patch('runpod.serverless.modules.lifecycle.LifecycleManager')
-    def test_start_worker(self, mock_worker_life, mock_worker_life_heartbeat, mock_job_get):
+    def test_start_worker(self, mock_worker_life, mock_job_get):
         '''
         Tests start_worker
         '''
-        os.environ['DEBUG'] = 'true'
-
         pod_worker.start_worker()
-        # print(os.environ.get('DEBUG', None))
+
+        mwl_instance = mock_worker_life.return_value
 
         mock_worker_life.assert_called_once_with()
-        mock_worker_life_heartbeat.assert_called_once_with()
-        mock_job_get.assert_called_once_with(mock_worker_life.worker_id)
+        mwl_instance.heartbeat_ping.assert_called_once_with()
+        mock_job_get.assert_called_once_with(mwl_instance.worker_id)
 
     # @patch('os.path.exists', return_value=False)
     # @patch('shutil.rmtree')
